/**
 * Encrypts a string to a binary-safe string using the XXTEA encode algorithm and then Base64 encode
 *
 * @param string the string to encrypt
 * @param string the key to decrypt the string
 * @return string the encrypted string
 * @see #xxTeaEncrypt(String, String)
 * @see #base64Encode(String)
 */

function fastEncrypt(str, key)
{
	return base64Encode(xxTeaEncrypt(str, key));
};

/**
 * Decrypts a string using the Base64 decode algorithm and then XXTEA decode
 *
 * @param string the string to encrypt
 * @param string the key to encrypted the string
 * @return string the hashed string
 * @see #xxTeaDecrypt(String, String)
 * @see #base64Decode(String)
 */

function fastDecrypt(str, key)
{
	return xxTeaDecrypt(base64Decode(str), key);
};

/**
 * Encrypts a string to a binary-safe string using the XXTEA encode algorithm and then Base64 encode
 *
 * @param string the string to encrypt
 * @param string the key to decrypt the string
 * @return string the encrypted string
 * @see #blowfishSetKey(String)
 * @see #blowfishEncrypt(String, String)
 * @see #base64Encode(String)
 */

function secureEncrypt(str, key)
{
	blowfishSetKey(key);
	return base64Encode(blowfishEncrypt(str));
};

/**
 * Decrypts a string using the Base64 decode algorithm and then XXTEA decode
 *
 * @param string the string to encrypt
 * @param string the key to encrypted the string
 * @return string the hashed string
 * @see #blowfishSetKey(String)
 * @see #blowfishDecrypt(String, String)
 * @see #base64Decodes(String)
 */

function secureDecrypt(str, key)
{
	blowfishSetKey(key);
	return blowfishDecrypt(base64Decode(str));
};

function md5(str)
{
	return littleEndianArrayToHex(md5_binary(str));
};

var HEX_BROKEN = "Hex invalid";
var BASE64_BROKEN = "Inproperly padded Base64 input";


/**
 * Calculate the MD5 hash.
 *
 * @param string the string to hash
 * @return string the hashed string
 * @author www.farfarfar.com
 * @version 0.1
 */



function sha1(str)
{
	return bigEndianArrayToHex(sha1_binary(str));
};

/**
 * Calculate the SHA-1 hash.
 *
 * @param string the string to hash
 * @return string the hashed string
 * @author www.farfarfar.com
 * @version 0.1
 */



function sha2(str)
{
	return bigEndianArrayToHex(sha2_binary(str));
};
